@@ -177,12 +177,21 @@ class HTTPClient(_BaseHTTPClient):
             if kwargs.get('insecure', False) is True:
                 self.session.verify = False
             else:
-                if kwargs.get('cacert', None) is not '':
+                if kwargs.get('cacert', None) != '':
                     self.session.verify = kwargs.get('cacert', True)
 
             self.session.cert = (kwargs.get('cert_file'),
                                  kwargs.get('key_file'))
 
+    def __del__(self):
+        if self.session:
+            try:
+                self.session.close()
+            except Exception as e:
+                LOG.exception(e)
+            finally:
+                self.session = None
+
     @staticmethod
     def parse_endpoint(endpoint):
         return netutils.urlsplit(endpoint)
@@ -270,6 +279,7 @@ class HTTPClient(_BaseHTTPClient):
                                         conn_url,
                                         data=data,
                                         headers=headers,
+                                        timeout=self.timeout,
                                         **kwargs)
         except requests.exceptions.Timeout as e:
             message = ("Error communicating with %(url)s: %(e)s" %
